.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/tb-gateway.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/tb-gateway
    .. image:: https://readthedocs.org/projects/tb-gateway/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://tb-gateway.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/tb-gateway/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/tb-gateway
    .. image:: https://img.shields.io/pypi/v/tb-gateway.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/tb-gateway/
    .. image:: https://img.shields.io/conda/vn/conda-forge/tb-gateway.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/tb-gateway
    .. image:: https://pepy.tech/badge/tb-gateway/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/tb-gateway
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/tb-gateway

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

===========
tb-gateway
===========


    Add a short description here!


A longer description of your project goes here...


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.6. For details and usage
information on PyScaffold see https://pyscaffold.org/.
